"""
Module handes Dicord functionality
"""
import json
import requests

class DiscordEndpointNotSupported(Exception):
    pass

class DiscordAPI():

    base_url = "https://discordapp.com/api/"

    def __init__(self, channel_id, bot_token):
        self.channel_id = channel_id
        self.bot_token = bot_token

    def get_headers(self):
        return  { "Authorization":"Bot {}".format(self.bot_token),
            "User-Agent":"",
            "Content-Type":"application/json", }
    

    def get_api_url(self, endpoint):
        if endpoint == 'messages':
            return "{}/channels/{}/messages".format(self.base_url, self.channel_id)
        else:
            raise DiscordEndpointNotSupported

    def send_message(self, content):
        json_payload =  json.dumps({"content": content})
        r = requests.post(self.get_api_url('messages'), headers = self.get_headers(), data = json_payload)



from setuptools import setup

setup(name='ks_ci',
      version='1.3',
      description='KS CI Bundle',
      long_description='CI scripts used in dev environment of the www.sarmacja.org community',
      author='Maciej Poleszczyk',
      author_email='mpoleszczyk@wp.pl',
      packages=['ks_ci'],
      license='MIT',
      url='https://github.com/poleszcz/ks-ci-bundle',
      python_requires='>=3',
      scripts=['bin/ks_ci_helper.py']
     )


#!/usr/bin/python3

from junitparser import JUnitXml
import argparse
import ks_ci.discord

parser = argparse.ArgumentParser(description='Bundle of ci helpers')
subparsers = parser.add_subparsers(help='sub-command help')
parser_ut2discord = subparsers.add_parser('ut2discord', help='Help for ut2discord command')
parser_ut2discord.add_argument('--junit-report', type=str, required=True, dest='junit_report')
parser_ut2discord.add_argument('--dsc-channel', type=str, required=True, dest='dsc_channel')
parser_ut2discord.add_argument('--bot-token', type=str, required=True, dest='bot_token')
parser_ut2discord.add_argument('--rev', type=str, required=True, dest='vcs_rev')

args = parser.parse_args()

discordApi = ks_ci.discord.DiscordAPI(args.dsc_channel, args.bot_token)

xml = JUnitXml.fromfile(args.junit_report)
failures = 0
tests = 0
errors = 0
for suite in xml:
    failures = failures + suite.failures
    tests = tests + suite.tests
    errors = errors + suite.errors

icon = ":green_heart:"
if failures + errors > 0:
    icon = ":no_entry:"

discordApi.send_message("{} Revision: {}. Total tests: {}, failed: {}, errors: {}.".format(icon, args.vcs_rev, tests, failures, errors))
